@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2018 Joël Krähemann
+ * Copyright (C) 2005-2019 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -260,11 +260,7 @@ ags_recall_dssi_set_property(GObject *gobject,
   recall_dssi = AGS_RECALL_DSSI(gobject);
 
   /* get recall mutex */
-  pthread_mutex_lock(ags_recall_get_class_mutex());
-  
-  recall_mutex = AGS_RECALL(gobject)->obj_mutex;
-  
-  pthread_mutex_unlock(ags_recall_get_class_mutex());
+  recall_mutex = AGS_RECALL_GET_OBJ_MUTEX(recall_dssi);
 
   switch(prop_id){
   case PROP_PLUGIN:
@@ -331,11 +327,7 @@ ags_recall_dssi_get_property(GObject *gobject,
   recall_dssi = AGS_RECALL_DSSI(gobject);
 
   /* get recall mutex */
-  pthread_mutex_lock(ags_recall_get_class_mutex());
-  
-  recall_mutex = AGS_RECALL(gobject)->obj_mutex;
-  
-  pthread_mutex_unlock(ags_recall_get_class_mutex());
+  recall_mutex = AGS_RECALL_GET_OBJ_MUTEX(recall_dssi);
 
   switch(prop_id){
   case PROP_PLUGIN:
@@ -413,11 +405,7 @@ ags_recall_dssi_set_ports(AgsPlugin *plugin, GList *port)
   recall_dssi = AGS_RECALL_DSSI(plugin);
 
   /* get recall mutex */
-  pthread_mutex_lock(ags_recall_get_class_mutex());
-  
-  recall_mutex = AGS_RECALL(recall_dssi)->obj_mutex;
-  
-  pthread_mutex_unlock(ags_recall_get_class_mutex());
+  recall_mutex = AGS_RECALL_GET_OBJ_MUTEX(recall_dssi);
 
   /* get some fields */
   pthread_mutex_lock(recall_mutex);
@@ -441,12 +429,8 @@ ags_recall_dssi_set_ports(AgsPlugin *plugin, GList *port)
   pthread_mutex_unlock(recall_mutex);
 
   /* get base plugin mutex */
-  pthread_mutex_lock(ags_base_plugin_get_class_mutex());
+  base_plugin_mutex = AGS_BASE_PLUGIN_GET_OBJ_MUTEX(dssi_plugin);
   
-  base_plugin_mutex = AGS_BASE_PLUGIN(dssi_plugin)->obj_mutex;
-  
-  pthread_mutex_unlock(ags_base_plugin_get_class_mutex());
-
   /* get plugin port */
   pthread_mutex_lock(base_plugin_mutex);
 
@@ -467,11 +451,7 @@ ags_recall_dssi_set_ports(AgsPlugin *plugin, GList *port)
       current_plugin_port = AGS_PLUGIN_PORT(plugin_port->data);
 
       /* get plugin port mutex */
-      pthread_mutex_lock(ags_plugin_port_get_class_mutex());
-      
-      plugin_port_mutex = current_plugin_port->obj_mutex;
-
-      pthread_mutex_unlock(ags_plugin_port_get_class_mutex());
+      plugin_port_mutex = AGS_PLUGIN_PORT_GET_OBJ_MUTEX(current_plugin_port);
       
       if(ags_plugin_port_test_flags(current_plugin_port,
 				    AGS_PLUGIN_PORT_CONTROL)){
@@ -648,11 +628,7 @@ ags_recall_dssi_load(AgsRecallDssi *recall_dssi)
   }
 
   /* get recall mutex */
-  pthread_mutex_lock(ags_recall_get_class_mutex());
-  
-  recall_mutex = AGS_RECALL(recall_dssi)->obj_mutex;
-  
-  pthread_mutex_unlock(ags_recall_get_class_mutex());
+  recall_mutex = AGS_RECALL_GET_OBJ_MUTEX(recall_dssi);
 
   /* get some fields */
   pthread_mutex_lock(recall_mutex);
@@ -725,11 +701,7 @@ ags_recall_dssi_load_ports(AgsRecallDssi *recall_dssi)
   }
 
   /* get recall mutex */
-  pthread_mutex_lock(ags_recall_get_class_mutex());
-  
-  recall_mutex = AGS_RECALL(recall_dssi)->obj_mutex;
-  
-  pthread_mutex_unlock(ags_recall_get_class_mutex());
+  recall_mutex = AGS_RECALL_GET_OBJ_MUTEX(recall_dssi);
 
   /* get some fields */
   pthread_mutex_lock(recall_mutex);
@@ -755,11 +727,7 @@ ags_recall_dssi_load_ports(AgsRecallDssi *recall_dssi)
   pthread_mutex_unlock(recall_mutex);
 
   /* get base plugin mutex */
-  pthread_mutex_lock(ags_base_plugin_get_class_mutex());
-  
-  base_plugin_mutex = AGS_BASE_PLUGIN(dssi_plugin)->obj_mutex;
-  
-  pthread_mutex_unlock(ags_base_plugin_get_class_mutex());
+  base_plugin_mutex = AGS_BASE_PLUGIN_GET_OBJ_MUTEX(dssi_plugin);
 
   /* get port descriptor */
   pthread_mutex_lock(base_plugin_mutex);
@@ -783,11 +751,7 @@ ags_recall_dssi_load_ports(AgsRecallDssi *recall_dssi)
       current_plugin_port = AGS_PLUGIN_PORT(plugin_port->data);
 
       /* get plugin port mutex */
-      pthread_mutex_lock(ags_plugin_port_get_class_mutex());
-      
-      plugin_port_mutex = current_plugin_port->obj_mutex;
-
-      pthread_mutex_unlock(ags_plugin_port_get_class_mutex());
+      plugin_port_mutex = AGS_PLUGIN_PORT_GET_OBJ_MUTEX(current_plugin_port);
 
       if(ags_plugin_port_test_flags(current_plugin_port,
 				    AGS_PLUGIN_PORT_CONTROL)){
@@ -1001,11 +965,7 @@ ags_recall_dssi_find(GList *recall,
   while(recall != NULL){
     if(AGS_IS_RECALL_DSSI(recall->data)){
       /* get recall mutex */
-      pthread_mutex_lock(ags_recall_get_class_mutex());
-  
-      recall_mutex = AGS_RECALL(recall->data)->obj_mutex;
-  
-      pthread_mutex_unlock(ags_recall_get_class_mutex());
+      recall_mutex = AGS_RECALL_GET_OBJ_MUTEX(recall->data);
 
       /* check filename and effect */
       pthread_mutex_lock(recall_mutex);
