@@ -231,11 +231,7 @@ ags_file_launch_set_property(GObject *gobject,
   file_launch = AGS_FILE_LAUNCH(gobject);
 
   /* get file id ref mutex */
-  pthread_mutex_lock(ags_file_launch_get_class_mutex());
-  
-  file_launch_mutex = file_launch->obj_mutex;
-  
-  pthread_mutex_unlock(ags_file_launch_get_class_mutex());  
+  file_launch_mutex = AGS_FILE_LAUNCH_GET_OBJ_MUTEX(file_launch);
   
   switch(prop_id){
   case PROP_NODE:
@@ -325,11 +321,7 @@ ags_file_launch_get_property(GObject *gobject,
   file_launch = AGS_FILE_LAUNCH(gobject);
 
   /* get file id ref mutex */
-  pthread_mutex_lock(ags_file_launch_get_class_mutex());
-  
-  file_launch_mutex = file_launch->obj_mutex;
-  
-  pthread_mutex_unlock(ags_file_launch_get_class_mutex());
+  file_launch_mutex = AGS_FILE_LAUNCH_GET_OBJ_MUTEX(file_launch);
     
   switch(prop_id){
   case PROP_NODE:
